.. currentmodule:: sardana.tango.pool.PseudoMotor

:mod:`~sardana.tango.pool.PseudoMotor`
=========================================

.. automodule:: sardana.tango.pool.PseudoMotor

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PseudoMotor`
    * :class:`PseudoMotorClass`

PseudoMotor
------------

.. inheritance-diagram:: PseudoMotor
    :parts: 1
    
.. autoclass:: PseudoMotor
    :show-inheritance:
    :members:
    :undoc-members:

PseudoMotorClass
----------------

.. inheritance-diagram:: PseudoMotorClass
    :parts: 1
    
.. autoclass:: PseudoMotorClass
    :show-inheritance:
    :members:
    :undoc-members:

